pub struct Range {
pub start: Position,
pub end: Position,
}Expand description
Range.
Ranges are used to represent start and end positions of text in a text file, which is particularly useful for error reporting and debugging purposes.
Fields
start: PositionStart position.
end: PositionEnd position.
Implementations