warning

Macro warning 

macro_rules! warning {
    (&mut $sink:expr, $($arg:tt)+) => { ... };
    ($($arg:tt)*) => { ... };
}
Creates a diagnostic with warning severity.

This macro creates a diagnostic message with Severity::Warning, using either a static string or a format string as an argument.

The diagnostic will include file, line and column information.

Examples

use zrx_diagnostic::warning;

// Create diagnostic with static string
let diagnostic = warning!("Static");

// Create diagnostic with format string
let diagnostic = warning!("Format: {}", true);