Range

Struct Range 

pub struct Range {
    pub start: Position,
    pub end: Position,
}
Range.

Ranges are used to represent start and end positions of text in a text file, which is particularly useful for error reporting and debugging purposes.

Fields

start: Position

Start position.

end: Position

End position.

Implementations

Source

impl Range

pub fn new<S, E>(start: S, end: E) -> Range
where S: Into<Position>, E: Into<Position>,

Creates a range with the given start and end positions.

Examples
use zrx_diagnostic::location::{Position, Range};

// Create range
let range = Range::new(
    Position::new(0, 0),
    Position::new(4, 0)
);