Builder

Struct Builder 

pub struct Builder { /* private fields */ }
Filter builder.

This data type uses a Slab to store conditions efficiently, which makes it possible to keep indices stable when adding or removing expressions. It allows users to modify a Filter dynamically, and rebuild it on-the-fly after all modifications were made.

Implementations

Source

impl Builder

pub fn insert<T>(&mut self, expr: T) -> usize
where T: Into<Expression>,

Inserts an expression into the filter and returns its index.

This method adds an Expression to the filter builder, and returns the index of the inserted condition, which can be used to remove it.

Note that the expression is immediately converted into a [Condition] for performance reasons, which means it cannot be recovered. If we’d store expressions directly, removing or inserting new expressions into the filter would mandate recompilation of all expressions.

Examples
use zrx_id::expression::Filter;
use zrx_id::{selector, Expression};

// Create filter builder and insert expression
let mut builder = Filter::builder();
builder.insert(Expression::any(|expr| {
    expr.with(selector!(location = "**/*.jpg")?)?
        .with(selector!(location = "**/*.png")?)
})?);
pub fn remove(&mut self, index: usize)

Removes an expression from the filter.

Examples
use zrx_id::expression::Filter;
use zrx_id::{selector, Expression};

// Create filter builder and insert expression
let mut builder = Filter::builder();
builder.insert(Expression::any(|expr| {
    expr.with(selector!(location = "**/*.jpg")?)?
        .with(selector!(location = "**/*.png")?)
})?);

// Remove expression
builder.remove(0);
pub fn build(self) -> Result<Filter, Error>

Builds the filter.

Errors

Returns Error::Matcher if the underlying matcher can’t be built.

Examples
use zrx_id::expression::Filter;
use zrx_id::{selector, Expression};

// Create filter builder and insert expression
let mut builder = Filter::builder();
builder.insert(Expression::any(|expr| {
    expr.with(selector!(location = "**/*.jpg")?)?
        .with(selector!(location = "**/*.png")?)
})?);

// Create filter from builder
let filter = builder.build()?;
Source

impl Builder

pub fn len(&self) -> usize

Returns the number of expressions.

pub fn is_empty(&self) -> bool

Returns whether there are any expressions.