pub enum Atom<'a> {
Literal(&'a str),
Wildcard(Wildcard),
Character(Character<'a>),
Group(Vec<Segments<'a>>),
}Expand description
Atom.
Atoms are the basic building blocks of Segments, representing literals,
wildcards, character classes and groups of alternatives. Each Segment
contains a set of atoms that define which Specificity the segment has,
where specificity is determined by the least specific atom in the segment.
Variants
Literal(&'a str)
Literal, e.g., main.rs
Wildcard(Wildcard)
Wildcard, i.e., ?, *, or **.
Character(Character<'a>)
Character class, e.g., [xyz].
Group(Vec<Segments<'a>>)
Alternate group, e.g., {*.rs,*.md}.