pub struct Character<'a> { /* private fields */ }Expand description
Character class.
For our case, we do not need to know the exact structure of the character
class, as we’ll score it as a single character anyway, same as *. We also
don’t care whether it’s negated or not, as that doesn’t affect scoring as
well. Therefore, we can just store the string slices.